summaryrefslogtreecommitdiffstats
path: root/languages/ruby/debugger/breakpoint.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/ruby/debugger/breakpoint.cpp')
-rw-r--r--languages/ruby/debugger/breakpoint.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/languages/ruby/debugger/breakpoint.cpp b/languages/ruby/debugger/breakpoint.cpp
index f210e359..c9a91ec4 100644
--- a/languages/ruby/debugger/breakpoint.cpp
+++ b/languages/ruby/debugger/breakpoint.cpp
@@ -23,11 +23,11 @@
#include <klocale.h>
-#include <qfileinfo.h>
-#include <qfontmetrics.h>
-#include <qpainter.h>
-#include <qregexp.h>
-#include <qstring.h>
+#include <tqfileinfo.h>
+#include <tqfontmetrics.h>
+#include <tqpainter.h>
+#include <tqregexp.h>
+#include <tqstring.h>
#include <stdio.h>
@@ -67,12 +67,12 @@ Breakpoint::~Breakpoint()
/***************************************************************************/
-QString Breakpoint::dbgRemoveCommand() const
+TQString Breakpoint::dbgRemoveCommand() const
{
// if (dbgId_>0)
-// return QString("delete %1").arg(dbgId_); // gdb command - not translatable
+// return TQString("delete %1").arg(dbgId_); // gdb command - not translatable
- return QString();
+ return TQString();
}
/***************************************************************************/
@@ -115,9 +115,9 @@ void Breakpoint::setActive(int active, int id)
/***************************************************************************/
-QString Breakpoint::statusDisplay(int activeFlag) const
+TQString Breakpoint::statusDisplay(int activeFlag) const
{
- QString status="";
+ TQString status="";
if (!s_enabled_)
status = i18n("Disabled");
else
@@ -141,7 +141,7 @@ QString Breakpoint::statusDisplay(int activeFlag) const
/***************************************************************************/
/***************************************************************************/
-FilePosBreakpoint::FilePosBreakpoint(const QString &fileName, int lineNum,
+FilePosBreakpoint::FilePosBreakpoint(const TQString &fileName, int lineNum,
bool temporary, bool enabled)
: Breakpoint(temporary, enabled),
fileName_(fileName),
@@ -157,13 +157,13 @@ FilePosBreakpoint::~FilePosBreakpoint()
/***************************************************************************/
-QString FilePosBreakpoint::dbgSetCommand() const
+TQString FilePosBreakpoint::dbgSetCommand() const
{
- QString cmdStr;
+ TQString cmdStr;
if (fileName_.isEmpty())
- cmdStr = QString("break %1").arg(lineNo_); // gdb command - not translatable
+ cmdStr = TQString("break %1").arg(lineNo_); // gdb command - not translatable
else {
- cmdStr = QString("break %1:%2").arg(fileName_).arg(lineNo_);
+ cmdStr = TQString("break %1:%2").arg(fileName_).arg(lineNo_);
}
if (isTemporary())
@@ -192,26 +192,26 @@ bool FilePosBreakpoint::match(const Breakpoint *brkpt) const
/***************************************************************************/
-QString FilePosBreakpoint::location(bool compact)
+TQString FilePosBreakpoint::location(bool compact)
{
if (compact)
- return QFileInfo(fileName_).fileName()+":"+QString::number(lineNo_);
+ return TQFileInfo(fileName_).fileName()+":"+TQString::number(lineNo_);
- return fileName_+":"+QString::number(lineNo_);
+ return fileName_+":"+TQString::number(lineNo_);
}
/***************************************************************************/
-void FilePosBreakpoint::setLocation(const QString& location)
+void FilePosBreakpoint::setLocation(const TQString& location)
{
- QRegExp regExp1("(.*):(\\d+)$");
+ TQRegExp regExp1("(.*):(\\d+)$");
regExp1.setMinimal(true);
if ( regExp1.search(location, 0) >= 0 )
{
- QString t = regExp1.cap(1);
- QString dirPath = QFileInfo(t).dirPath();
+ TQString t = regExp1.cap(1);
+ TQString dirPath = TQFileInfo(t).dirPath();
if ( dirPath == "." )
- fileName_ = QFileInfo(fileName_).dirPath()+"/"+regExp1.cap(1);
+ fileName_ = TQFileInfo(fileName_).dirPath()+"/"+regExp1.cap(1);
else
fileName_ = regExp1.cap(1);
@@ -223,7 +223,7 @@ void FilePosBreakpoint::setLocation(const QString& location)
/***************************************************************************/
/***************************************************************************/
-Watchpoint::Watchpoint(const QString& varName, bool temporary, bool enabled)
+Watchpoint::Watchpoint(const TQString& varName, bool temporary, bool enabled)
: Breakpoint(temporary, enabled),
varName_(varName)
{
@@ -237,9 +237,9 @@ Watchpoint::~Watchpoint()
/***************************************************************************/
-QString Watchpoint::dbgSetCommand() const
+TQString Watchpoint::dbgSetCommand() const
{
- return QString("watch ")+varName_; // gdb command - not translatable
+ return TQString("watch ")+varName_; // gdb command - not translatable
}
/***************************************************************************/
@@ -263,7 +263,7 @@ bool Watchpoint::match(const Breakpoint* brkpt) const
/***************************************************************************/
/***************************************************************************/
-Catchpoint::Catchpoint(const QString& varName, bool temporary, bool enabled)
+Catchpoint::Catchpoint(const TQString& varName, bool temporary, bool enabled)
: Breakpoint(temporary, enabled),
varName_(varName)
{
@@ -277,9 +277,9 @@ Catchpoint::~Catchpoint()
/***************************************************************************/
-QString Catchpoint::dbgSetCommand() const
+TQString Catchpoint::dbgSetCommand() const
{
- return QString("catch ")+varName_; // gdb command - not translatable
+ return TQString("catch ")+varName_; // gdb command - not translatable
}
/***************************************************************************/
@@ -303,7 +303,7 @@ bool Catchpoint::match(const Breakpoint* brkpt) const
/***************************************************************************/
/***************************************************************************/
-FunctionBreakpoint::FunctionBreakpoint(const QString& functionName, bool temporary, bool enabled)
+FunctionBreakpoint::FunctionBreakpoint(const TQString& functionName, bool temporary, bool enabled)
: Breakpoint(temporary, enabled),
m_functionName(functionName)
{
@@ -317,9 +317,9 @@ FunctionBreakpoint::~FunctionBreakpoint()
/***************************************************************************/
-QString FunctionBreakpoint::dbgSetCommand() const
+TQString FunctionBreakpoint::dbgSetCommand() const
{
- return QString("break ")+m_functionName; // gdb command - not translatable
+ return TQString("break ")+m_functionName; // gdb command - not translatable
}
/***************************************************************************/